@@ -10,5 +10,8 @@ function(x, theta, ...)
     thetahat <- theta(x, ...)
     jack.bias <- (n - 1) * (mean(u) - thetahat)
     jack.se <- sqrt(((n - 1)/n) * sum((u - mean(u))^2))
-    return(list(jack.se, jack.bias, jack.val = u, call=call))
+    return(list(jack.se=jack.se, 
+                jack.bias=jack.bias, 
+                jack.values = u, 
+                call=call))
 }
